/*******************************************************************
"Structural change and the Kaldor facts in a growth model with relative price effects and non-Gorman preferences"
by Timo Boppart
(Do file of all empirical results in the main text)
********************************************************************/
clear
clear matrix
set mem 4g

/*******************************************************************
Set Directory
********************************************************************/

cd "I:\timo\revision\replication\final do files and data\Datasets"

/*******************************************************************
Figures 1&2 from the aggregate BEA data
********************************************************************/

use BEAannual

gen good_share = goods/totexp
gen log_good_share = log(good_share)

gen per_capita_exp = totexp/pop_size
gen log_per_capita_exp=log(per_capita_exp)

gen real_per_capita_exp = totexp/(pop_size * p_serv)
gen log_real_per_capita_exp = log(real_per_capita_exp)
gen log_p_service=log(p_service)
gen log_p_good=log(p_good)
gen log_pgps=log(p_good/p_service)


/*******************************************************************
Figure 1: Expenditure share of goods - time on a logarithmic scale
********************************************************************/
reg log_good_share year
predict lfit_year
gen e_lfit_year = exp(lfit_year)
reg good_shar e_lfit_year, nocons
matrix B = e(b)
scalar corrbeta1=B[1,1]
gen corrected_lfit_year = corrbeta1*e_lfit_year
twoway (line good_share year, sort) (line corrected_lfit_year year, lpattern(dash) sort), yscale(log range(0.3 0.6)) ylabel( 0.3 "0.30"0.35 "0.35" 0.40 "0.40" 0.45 "0.45" 0.5 "0.50" 0.55 "0.55" 0.6 "0.60", gmin angle(horizontal)) xtitle() xlabel(1950(10)2010) legend(off)

/*******************************************************************
Figure 2: Relative price between goods and services - time on a logarithmic scale
********************************************************************/
gen rel_price = p_good/p_servi
gen log_rel_price = log(rel_pric)

reg log_rel_pr year
predict fit_rel
gen e_fit_rel = exp(fit_rel)
reg rel_price e_fit_rel, nocons
matrix C = e(b)
scalar corrbeta2=C[1,1]
gen corrected_fit_rel = corrbeta2*e_fit_rel
twoway (line rel_price year, sort) (line corrected_fit_rel year, lpattern(dash) sort), yscale(log) ylabel( 1 "1" 1.5 "1.5" 2 "2" 2.5 "2.5" 3 "3" , gmin angle(horizontal)) xlabel(1950(10)2010) legend(off)

/*******************************************************************
Figure 3: Relative quanitity of services over time
********************************************************************/

gen realquantot=(services/p_services)/(goods/p_goods)
scalar starting=realquantot[1]
replace realquantot=realquantot/starting

gen fit_real_quant=corrected_fit_rel*(1-corrected_lfit_year)/corrected_lfit_year
scalar starting_realquant_fit=fit_real_quant[1]
replace fit_real_quant=fit_real_quant/starting_realquant_fit


twoway (line realquantot year, lpattern(solid)) (line fit_real_quant year, lpattern(dash) sort), ylabel( 0.9 "0.9" 1.0 "1.0" 1.1 "1.1" 1.2 "1.2" 1.3 "1.3" 1.4 "1.4") ytitle(XX) xtitle() legend(off) xlabel(1950(10)2010)


/*******************************************************************
Figures 4&7 & Table I from the CEX data
********************************************************************/
clear

use 1986_2011_cex
set more off

drop if food==0
drop if totexp == 0
drop if income_after_taxes_transfers<= 0
drop if income_after_taxes_transfers ==.
drop if year<=1985
drop if good_share<=0
drop if good_share>1

set more off
gen double perslt18_share=perslt18/fam_size
gen double persot64_share=persot64/fam_size
replace fam_size=11 if fam_size>10
recode ref_race (5=4) if year>=2003
recode ref_race (6=3)
destring cutenure, replace
recode cutenure (2=1) (3=1)(6=5)

gen log_totexp = log(totexp_equi)
gen log_good_share = log(good_share)
gen log_income = log(income_after_taxes_transfers/equiv_s)
gen log_finca = log(finca/equiv_s)

/*******************************************************************
Figure 4: good shares over time by income quintiles on a logarithmic scale
********************************************************************/

*quintiles
by year, sort : egen float quant_20 = pctile(income_after_taxes_transfers/equiv_scale), p(20)
by year, sort : egen float quant_40 = pctile(income_after_taxes_transfers/equiv_scale), p(40)
by year, sort : egen float quant_60 = pctile(income_after_taxes_transfers/equiv_scale), p(60)
by year, sort : egen float quant_80 = pctile(income_after_taxes_transfers/equiv_scale), p(80)

by year, sort : egen float meanq1 = mean(good_share) if income_after_taxes_transfers/equiv_scale<quant_20
by year, sort : egen float meanq2 = mean(good_share) if income_after_taxes_transfers/equiv_scale<quant_40 & income_after_taxes_transfers/equiv_scale>=quant_20
by year, sort : egen float meanq3 = mean(good_share) if income_after_taxes_transfers/equiv_scale<quant_60 & income_after_taxes_transfers/equiv_scale>=quant_40
by year, sort : egen float meanq4 = mean(good_share) if income_after_taxes_transfers/equiv_scale<quant_80 & income_after_taxes_transfers/equiv_scale>=quant_60
by year, sort : egen float meanq5 = mean(good_share) if income_after_taxes_transfers/equiv_scale>=quant_80

twoway (line meanq1 year, sort lcolor(navy) lwidth(medthick) lpattern(dash)) (line meanq2 year, sort lcolor(orange) lwidth(medthick) lpattern(longdash_dot)) (line meanq3 year, sort lcolor(ltblue) lwidth(medthick) lpattern(solid)) (line meanq4 year, sort lcolor(cranberry) lwidth(medthick) lpattern(dash_dot_dot)) (line meanq5 year, sort lcolor(green) lwidth(medthick) lpattern(vshortdash)), yscale(log)  xlabel(1986 1990(5)2010) ylabel( 0.30 "0.30" 0.35 "0.35" 0.40 "0.40" 0.45 "0.45", gmin angle(horizontal)) xtitle() legend(  label(1 "AAAAAAA") label(2 "BBBBBBB") label(3 "CCCCCCC") label(4 "DDDDDDD") label(5 "EEEEEEE"))  

/*******************************************************************
Figure 7: good shares by income quintiles relative to average per equivalent scale expenditure level
********************************************************************/

by year, sort : gen float percentile = 20 if income_after_taxes_transfers/equiv_scale<quant_20
forvalues i=40(20)80{
local r =`i'-20
by year, sort : replace percentile = `i' if income_after_taxes_transfers/equiv_scale<quant_`i' & income_after_taxes_transfers/equiv_scale>=quant_`r'
}
by year, sort : replace percentile = 100 if income_after_taxes_transfers/equiv_scale>=quant_80

*collapse
collapse (mean) good_share totexp_equi, by(year percentile)

*take logs
gen log_totexp = log(totexp_equi)
gen log_good_share = log(good_share)

*regression on year dummies
xi: reg log_good_share log_totexp i.year
matrix B = e(b)

matrix list B

*correction of log_s_share
gen log_s_corrected = log_good_share

forvalues i=2/27 {
replace log_s_corrected = log_good_share - B[1,`i'] if year==1985+`i'
}

twoway (scatter  log_s_corrected  log_totexp) (lfit  log_s_corrected  log_totexp),xscale( range(7.7 9.55)) xlabel( 8 "8" 8.5 "8.5" 9 "9" 9.5 "9.5" ) ytitle(Y) xtitle(X) legend(off) ylabel( -0.8 "-0.8" -0.9 "-0.9" -1.0 "-1.0" -1.1 "-1.1" -1.2 "-1.2")

/*******************************************************************
Table I: Columns (1)&(2)
********************************************************************/
clear

use 1986_2011_cex
set more off

drop if food==0
drop if totexp == 0
drop if income_after_taxes_transfers<= 0
drop if income_after_taxes_transfers ==.
drop if year<=1985
drop if good_share<=0
drop if good_share>1

set more off
gen double perslt18_share=perslt18/fam_size
gen double persot64_share=persot64/fam_size
replace fam_size=11 if fam_size>10
recode ref_race (5=4) if year>=2003
recode ref_race (6=3)
destring cutenure, replace
recode cutenure (2=1) (3=1)(6=5)

gen log_totexp = log(totexp_equi)
gen log_good_share = log(good_share)
gen log_income = log(income_after_taxes_transfers/equiv_s)
gen log_finca = log(finca/equiv_s)

xtset quartal
xtivreg  log_good_share (log_totexp=log_income), fe 
estimates store tab1
xi: xtivreg  log_good_share (log_totexp=log_income) perslt18_sh persot64_sh i.fam_size i.region i.bls_urbn i.popsize sex_ref i.ref_race i.education1 age_ref, fe 
estimates store tab2

/*******************************************************************
Table I: Columns (4)&(5): durable consumption (house equipment + vehicles) excluded
********************************************************************/
gen vehicles=vehiclcq+vehiclpq
replace vehicles=cartkn+cartku+othvehpq_94bis2011+othvehcq_94bis2011 if year>1993
recode vehicles (.=0)

*new services/goods if durable items are excluded
drop good_share log_good_share totexp_equi log_totexp
gen good_share = (totexp-houseq-vehicles-service)/(totexp-houseq-vehicles)
gen totexp_equi = (totexp-houseq-vehicles)/equiv_s
gen log_totexp = log(totexp_equi)
gen log_good_share = log(good_share)


*Regressions: (4) IV and (5) OLS
xtset quartal
xi: xtivreg  log_good_share (log_totexp=log_income) perslt18_sh persot64_sh i.fam_size i.region i.bls_urbn i.popsize sex_ref i.ref_race i.education1 age_ref, fe 
estimates store tab4
xi: xtreg log_good_share log_totexp perslt18_sh persot64_sh i.fam_size i.region i.bls_urbn i.popsize sex_ref i.ref_race i.education1 age_ref, fe
estimates store tab5

/*******************************************************************
Table I: Column (3): PSID Data
********************************************************************/
clear

use psid

*Regression (3) PSID
xi: ivregress 2sls ln_gds_share perslt18_sh persot64_sh alaska_hawaii west south northcentral rural urban_small urban_big metropolitan fringe twoperson_hh threeperson_hh fourperson_hh fiveperson_hh sixperson_hh sevenperson_hh eightperson_hh nineperson_hh tenperson_hh elevenormoreperson_hh age_head female black hispanic indian asian pacific_islander other_race (log_totexp= ln_labinc_equvlscale) i.educa_head if year==2009
estimates store tab3

/**** Table I generator (unnecessary)***

# delimit ;
 estout tab1 tab2 tab3 tab4 tab5 using table1.tex, replace
       cells(b(star fmt(%9.3f)) se(par))
         stats(N r2  p,  fmt(%9.0f %9.3f %9.3f ) labels("Obs." "R$^{2}$" "Prob$>F$" ))      
 
         mlabels(, none)
         collabels ( "(1)" ,  lhs({\bf GLS})  begin("\hline "))
        
        prehead("
         \begin{table}
         \begin{center}
         {\begin{tabular}{lcccc} \hline ")
         posthead ("\hline")
         prefoot(" \hline") postfoot("\hline\hline
        \end{tabular}}
         \label{@title}        
 \end{center}
        \end{table}")
        starlevels(* 0.1 ** 0.05 *** 0.01)
       varwidth(10) modelwidth(10) style(tex);
# delimit cr
*****************************************************************************/
/*******************************************************************
Panel regression using price data as suggested by equation (41) in the main text. This regression generates the results discussed in the main text on page 34 ff. I.e., that the estimated epsilon=0.182 and gamma=0.410.
********************************************************************/
use 1986_2011_cex
set more off

sort year quarter

merge m:1 year using BEA29_12

drop if food==0
drop if totexp == 0
drop if income_after_taxes_transfers<= 0
drop if income_after_taxes_transfers ==.
drop if year<=1985

set more off
gen double perslt18_share=perslt18/fam_size
gen double persot64_share=persot64/fam_size
replace fam_size=11 if fam_size>10
recode ref_race (5=4) if year>=2003
recode ref_race (6=3)
destring cutenure, replace
recode cutenure (2=1) (3=1)(6=5)


gen log_totexp = log(totexp_equi)
gen log_good_share = log(good_share)
gen log_income = log(income_after_taxes_transfers/equiv_s)
gen log_finca = log(finca/equiv_s)

gen log_income_in_terms_of_services = log(income_after_taxes_transfers/(equiv_s*p_services))
***
gen rel_price=p_services/p_goods
gen exp_in_servprice=totexp_equi/p_services

gen log_rel_price=log(rel_price)
gen log_exp_in_servprice=log(exp_in_servprice)
gen log_p_goods=log(p_goods)
gen log_p_services=log(p_services)

ivreg log_good_share (log_exp_in_servprice = log_income_in_terms_of_services) log_rel_price



